/*
 * spi.h
 *
 *  Created on: Feb. 14, 2020
 *      Author: isecurity
 */

#ifndef MAIN_SPI_H_
#define MAIN_SPI_H_

extern "C" {

#include <stdio.h>
#include <stdint.h>
#include <stddef.h>
#include <string.h>

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "freertos/semphr.h"
#include "freertos/queue.h"

#include "driver/spi_master.h"
}

class Spi {

public:
	enum SpiPort
	{
		SPI,
		HSPI,
		VSPI,
	};

	enum SpiPinout
	{
		MOSI,
		MISO,
		SCLK,
		CS
	};
	static constexpr char vSpi[4] = {
			23,		//MOSI
			19, 	//MISO
			18,		//SCLK
			5		//CS SLAVE
	};

	static constexpr char hSpi[4] = {
			12,		//MOSI
			13,		//MISO
			15,		//SCLK
			14		//CS SLAVE
	};

	Spi(SpiPort spiPort = VSPI);

	virtual ~Spi();

	esp_err_t spiBusAddDevice(spi_host_device_t host,
			const spi_device_interface_config_t *dev_config, spi_device_handle_t *handle);

	esp_err_t spiBusRemoveDevice(spi_device_handle_t handle);

	esp_err_t spiDeviceTransmit(spi_device_handle_t handle, spi_transaction_t *trans_desc);

private:
	spi_bus_config_t buscfg;
	esp_err_t ret;

	static xQueueHandle rdySem;
};

#endif /* MAIN_SPI_H_ */
